#!/bin/bash

if [ "$#" -ne 2 ]; then
    echo "Need passphrase and proxy password"
    exit 1
fi

passphrase=$1
proxypass=$2

GIT_REPO=${GIT_REPO:="https://gitlab.cern.ch/dmc/gfal2.git"}
GIT_BRANCH=${GIT_BRANCH:="develop"}


set -x

function run_mock()
{
    /usr/bin/mock --disable-plugin=tmpfs --configdir=../mock-config/ -r dev-epel-7-x86_64 "$@"
}


if [ -z "$SKIP_INIT" ]; then
    run_mock init
fi
run_mock install lcov wget git java-1.8.0-openjdk
run_mock install voms-clients voms-config-vo-dteam lcg-CA

run_mock installdeps `ls -1 /afs/cern.ch/project/gd/www/dms/dmc/repos/el7/x86_64/gfal2-2.*.src.* | tail -1`

run_mock chroot 'wget "http://repo1.maven.org/maven2/org/codehaus/sonar/runner/sonar-runner-dist/2.4/sonar-runner-dist-2.4.zip"'
run_mock chroot 'unzip -o "sonar-runner-dist-2.4.zip"'
run_mock --copyin "/afs/cern.ch/user/a/aalvarez/public/sonar-runner.properties.gpg" /
run_mock chroot "gpg --batch --yes --passphrase ${passphrase} --output ./sonar-runner-2.4/conf/sonar-runner.properties -d sonar-runner.properties.gpg"

run_mock --copyin /afs/cern.ch/user/a/aalvarez/public/*.pem /
run_mock chroot "echo ${proxypass} | voms-proxy-init --rfc --voms dteam -pwstdin --cert /saketag-cert.pem --key /saketag-key.pem --out /tmp/proxy.pem"
run_mock chroot "echo ${proxypass} | openssl rsa -in /saketag-key.pem -out /saketag-key-no.pem -passin stdin"
run_mock chroot "chown root.root /*.pem"
run_mock chroot "chmod 0400 /*.pem"

run_mock chroot 'rm -rfv gfal2'
run_mock chroot "git clone \"${GIT_REPO}\" --depth=1 -b ${GIT_BRANCH}"
run_mock chroot "cd /gfal2; X509_USER_PROXY=/tmp/proxy.pem ./coverage.sh; export SONAR_RUNNER_OPTS=\"-Duser.timezone=+01:00 -Djava.security.egd=file:///dev/urandom\"; /sonar-runner-2.4/bin/sonar-runner -X"

